@@ -103,7 +103,7 @@ if (SecNum > 0) { ## at least one sample in second generation
     sex <- ifelse(gender == 1, 'male', 'female')
     mped <- pedigree(indID, fatherID, motherID, sex = sex, famid = famID)
     kmat <- as.matrix(kinship(mped))
-    alpha <- mvrnorm(1, mu = rep(0,nrow(kmat)), Sigma = 2*kmat*depend)
+    alpha <- mvrnorm(1, mu = rep(0,nrow(kmat)), Sigma = 2*kmat/depend) # covariance matrix variance = 1/depend
   }
   
   #------------------------------------------------------------------------------
